import { PluginCreator } from 'tailwindcss/types/config';

const buildState = (theme, { color, backgroundColor, borderColor }) => {
	return {
		color: theme(color),
		backgroundColor: theme(backgroundColor),
		borderColor: theme(borderColor),
		boxShadow: `0 3px ${theme(borderColor)}`,
		'&.button--blank': {
			color: theme(backgroundColor),
			backgroundColor: theme('colors.button.blank.background'),
			borderColor: theme('colors.button.blank.border'),
			boxShadow: `0 3px ${theme('colors.button.blank.border')}`,
		},
		'&:active:not(:disabled)': {
			boxShadow: `0 0 ${theme(borderColor)}`,
			transform: 'translateY(3px)',
		},
	};
};

const creator: PluginCreator = ({ addComponents, theme }) =>
	addComponents({
		'.button': {
			padding: `${theme('spacing.2')} ${theme('spacing.4')}`,
			margin: `${theme('spacing.2')} auto`,
			display: 'flex',
			justifyContent: 'center',
			width: '100%',
			alignItems: 'center',
			borderRadius: theme('borderRadius.lg'),
			border: '1px solid',
			textTransform: 'uppercase',
			fontWeight: theme('fontWeight.normal'),
			'&--none': buildState(theme, {
				color: 'colors.button.none.color',
				backgroundColor: 'colors.button.none.background',
				borderColor: 'colors.button.none.border',
			}),
			'&--none.button--blank': {
				color: theme('colors.button.blank.color'),
			},
			'&--info': buildState(theme, {
				color: 'colors.button.info.color',
				backgroundColor: 'colors.button.info.background',
				borderColor: 'colors.button.info.border',
			}),
			'&--success': buildState(theme, {
				color: 'colors.button.success.color',
				backgroundColor: 'colors.button.success.background',
				borderColor: 'colors.button.success.border',
			}),
			'&--warning': buildState(theme, {
				color: 'colors.button.warning.color',
				backgroundColor: 'colors.button.warning.background',
				borderColor: 'colors.button.warning.border',
			}),
			'&--error': buildState(theme, {
				color: 'colors.button.error.color',
				backgroundColor: 'colors.button.error.background',
				borderColor: 'colors.button.error.border',
			}),
			'&:disabled': {
				boxShadow: `0 0px ${theme('colors.button.disabled.border')}`,
				transform: 'translateY(3px)',
				cursor: 'not-allowed',
				color: theme('colors.button.disabled.color'),
				backgroundColor: theme('colors.button.disabled.background'),
				borderColor: theme('colors.button.disabled.border'),
			},
			'&--large': {
				height: '48px',
				fontSize: '20px',
			},
			'&--medium': {
				height: '40px',
				fontSize: '14px',
			},
			'&--small': {
				height: '26px',
				fontSize: '12px',
			},
			'&--pressed': {
				boxShadow: 'none',
				transform: 'translateY(3px)',
			},
		},
	});

export default creator;
