import path from 'path';
import type { Config } from 'tailwindcss';
import plugin from 'tailwindcss/plugin';

import button from './components/button';
import buttonGroup from './components/buttonGroup';
import calendar from './components/calendar';
import field from './components/field';
import grid from './components/grid';
import human from './components/human';
import list from './components/list';
import message from './components/message';
import modal from './components/modal';
import skeleton from './components/skeleton';
import table from './components/table';
import toaster from './components/toaster';
import mainTheme from './theme/main';

export default {
	content: [
		path.resolve(__dirname + '/../../../**/*.{js,ts,tsx}'),
		path.resolve(__dirname + '/../../stories/**/*.mdx'),
		'!**/node_modules/**',
	],
	safelist: [
		{
			pattern: /col-/,
			variants: ['sm', 'md', 'lg', 'xl'],
		},
		{
			pattern: /grid/,
			variants: ['sm', 'md', 'lg', 'xl'],
		},
		{
			pattern: /gap/,
		},
		{
			pattern: /text-[\d]?xl/,
		},
		{
			pattern: /m[tlbrxy]?-\d/,
		},
	],
	theme: {
		extend: {
			screens: {
				'lg-m': { min: '768px', max: '1024px' },
				'md-m': { min: '640px', max: '768px' },
				'sm-m': { min: '0', max: '639px' },
			},
			width: {
				'v-10': '100vw',
			},
			maxHeight: {
				'v-7': '70vh',
			},
			minHeight: {
				'v-10': '100vh',
			},
			borderWidth: {
				1: '1px',
			},
			...mainTheme,
		},
	},
	plugins: [
		plugin(button),
		plugin(buttonGroup),
		plugin(field),
		plugin(message),
		plugin(skeleton),
		plugin(table),
		plugin(grid),
		plugin(list),
		plugin(modal),
		plugin(calendar),
		plugin(human),
		plugin(toaster),
		function ({ addVariant }) {
			addVariant('child', '& > *');
		},
	],
	corePlugins: {
		float: false,
	},
} satisfies Config;
